=====
Usage
=====

To use clisops in a project:

    .. code-block:: python

        import clisops

For information on the configuration options available in clisops, see: https://roocs-utils.readthedocs.io/en/latest/configuration.html#clisops
